const expect = require('chai').expect
const {
  getClientDb,
  getMysqlClusterConn,
  makeAndConnect,
  makeMysqlPoolCluster,
  prepareQuery,
} = require('../index.js')

const dbList = {
  test1: {
    clientName: 'test1',
    dbName: 'db_client_1',
    hostName: 'default',
  },
  test2: {
    clientName: 'test2',
    dbName: 'db_client_2',
    hostName: 'remote1',
  },
}

const paramsToTest = [
  {
    host: 'localhost',
    name: 'default_select',
    password: 'test',
    port: 3306,
    user: 'developer_select',
  },
  {
    host: 'localhost',
    name: 'default',
    password: 'test',
    port: 3306,
    user: 'developer',
  },
  {
    host: 'localhost',
    name: 'remote1',
    password: 'test_pass',
    port: 3305,
    user: 'root',
  },
]

describe('#makes connections', () => {
  const paramsSingle =
    {
      database: 'testing',
      host: 'localhost',
      password: 'test',
      port: 3306,
      user: 'developer',
    }
  const paramsSingleMissing =
    {
      password: 'test_pass',
      user: 'root',
    }

  it('should make single conn', done => {
    makeAndConnect(paramsSingle).then(ret => {
      const result = 3306

      expect(ret.config.port).to.eql(result)
      done()
    })
  })
  it('should give error missing param', done => {
    makeAndConnect(paramsSingleMissing).then(err => {
      const result = 'cant connect to db'

      expect(err.err).to.eql(result)
      done()
    })
  })
  it('should connect to pool cluster', done => {
    const Cluster = makeMysqlPoolCluster(paramsToTest)
    const result = 3306
    Cluster.getConnection(
      'default',
      (err, connection) => {
        expect(connection.config.port).to.eql(result)
        done()
      })
  })
})

describe('#selects db', () => {
  it('should return db name', () => {
    const dbName = getClientDb('test1', dbList)
    const result = {
      dbName: 'db_client_1',
      hostName: 'default',
    }

    expect(dbName).to.deep.eql(result)
  })

  it('should return cluster conn   ds', done => {
    const Cluster = makeMysqlPoolCluster(paramsToTest)
    getMysqlClusterConn(Cluster, 'default', 'select').then(conn => {
      const result = 3306
      expect(conn.config.port).to.eql(result)
      done()
    }).catch(e => {
      console.log(e)
    })
  })

  it('should return cluster conn', () => {
    const dbName = getClientDb('test1', dbList)
    const Cluster = makeMysqlPoolCluster(paramsToTest)
    const hostName = dbName.hostName
    getMysqlClusterConn(Cluster, hostName, 'select').then(conn => {
      const result = 3306
      expect(conn.config.port).to.eql(result)
    })
  })
})

describe('#prepareQuery', () => {
  it('should return assemble query', done => {
    const queryString = 'insert into |.test set ?'
    const Cluster = makeMysqlPoolCluster(paramsToTest)
    const parsedValues = [{ param: 'P' }]
    prepareQuery(queryString, 'test1', dbList, Cluster, parsedValues, 'select', true)
      .then(res => {
        expect(res.formated).to.eql(' insert into db_client_1.test set `param` = \'P\'')
        done()
      }).catch(e => {
        console.log(e)
      })
  })
})

